# Profile_MaBoSS Package

This is a module that allow to personalize a general boolean model defined with MaBoSS.
Mutational and/or transcriptional/proteomic data data can be used.
It also allows to store and simulate multile personalized models in multiple conditions to compare them.
